# Anniversaires

#calendar(
@yearly 26/1/1992  8:00-18:00 Anniverssaire Nicolas Vaz
@yearly 24/3/1965  8:00-18:00 Anniverssaire Marie-Laure Vaz
@yearly 30/3/1953  8:00-18:00 Anniverssaire Antoine Vaz
@yearly 2/5/1977  8:00-18:00 Anniverssaire Caroline
@yearly 5/5/1945  8:00-18:00 Anniverssaire Marie-Emilie
@yearly 17/6/1952  8:00-18:00 Anniverssaire Jean-Pierre
@yearly 13/8/1990  8:00-18:00 Anniverssaire Matthieu Vaz
@yearly 16/9/1992  8:00-18:00 Anniverssaire Elise Vaz
@yearly 9/12/1964  8:00-18:00 Anniverssaire Nuno Vaz
)
